==> istio-model-v1alpha3-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TLSRouteFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TLSRouteFluent<A extends TLSRouteFluent<A>> extends Fluent<A>{
  public A addToMatch(Integer index,TLSMatchAttributes item);
  public A setToMatch(Integer index,TLSMatchAttributes item);
  public A addToMatch(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes... items);
  public A addAllToMatch(Collection<TLSMatchAttributes> items);
  public A removeFromMatch(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes... items);
  public A removeAllFromMatch(Collection<TLSMatchAttributes> items);
  public A removeMatchingFromMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TLSMatchAttributes> getMatch();
  public List<TLSMatchAttributes> buildMatch();
  public TLSMatchAttributes buildMatch(Integer index);
  public TLSMatchAttributes buildFirstMatch();
  public TLSMatchAttributes buildLastMatch();
  public TLSMatchAttributes buildMatchingMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  public Boolean hasMatchingMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  public A withMatch(List<TLSMatchAttributes> match);
  public A withMatch(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes... match);
  public Boolean hasMatch();
  public TLSRouteFluent.MatchNested<A> addNewMatch();
  public TLSRouteFluent.MatchNested<A> addNewMatchLike(TLSMatchAttributes item);
  public TLSRouteFluent.MatchNested<A> setNewMatchLike(Integer index,TLSMatchAttributes item);
  public TLSRouteFluent.MatchNested<A> editMatch(Integer index);
  public TLSRouteFluent.MatchNested<A> editFirstMatch();
  public TLSRouteFluent.MatchNested<A> editLastMatch();
  public TLSRouteFluent.MatchNested<A> editMatchingMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  public A addToRoute(Integer index,RouteDestination item);
  public A setToRoute(Integer index,RouteDestination item);
  public A addToRoute(io.fabric8.istio.api.networking.v1alpha3.RouteDestination... items);
  public A addAllToRoute(Collection<RouteDestination> items);
  public A removeFromRoute(io.fabric8.istio.api.networking.v1alpha3.RouteDestination... items);
  public A removeAllFromRoute(Collection<RouteDestination> items);
  public A removeMatchingFromRoute(Predicate<RouteDestinationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRoute instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteDestination> getRoute();
  public List<RouteDestination> buildRoute();
  public RouteDestination buildRoute(Integer index);
  public RouteDestination buildFirstRoute();
  public RouteDestination buildLastRoute();
  public RouteDestination buildMatchingRoute(Predicate<RouteDestinationBuilder> predicate);
  public Boolean hasMatchingRoute(Predicate<RouteDestinationBuilder> predicate);
  public A withRoute(List<RouteDestination> route);
  public A withRoute(io.fabric8.istio.api.networking.v1alpha3.RouteDestination... route);
  public Boolean hasRoute();
  public TLSRouteFluent.RouteNested<A> addNewRoute();
  public TLSRouteFluent.RouteNested<A> addNewRouteLike(RouteDestination item);
  public TLSRouteFluent.RouteNested<A> setNewRouteLike(Integer index,RouteDestination item);
  public TLSRouteFluent.RouteNested<A> editRoute(Integer index);
  public TLSRouteFluent.RouteNested<A> editFirstRoute();
  public TLSRouteFluent.RouteNested<A> editLastRoute();
  public TLSRouteFluent.RouteNested<A> editMatchingRoute(Predicate<RouteDestinationBuilder> predicate);
  public interface MatchNested<N> extends Nested<N>,TLSMatchAttributesFluent<TLSRouteFluent.MatchNested<N>>{
    public N and();
    public N endMatch();
    
  }
  public interface RouteNested<N> extends Nested<N>,RouteDestinationFluent<TLSRouteFluent.RouteNested<N>>{
    public N and();
    public N endRoute();
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TLSRouteFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TLSRouteFluent<A extends TLSRouteFluent<A>> extends Fluent<A>{
  public A addToMatch(int index,TLSMatchAttributes item);
  public A setToMatch(int index,TLSMatchAttributes item);
  public A addToMatch(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes... items);
  public A addAllToMatch(Collection<TLSMatchAttributes> items);
  public A removeFromMatch(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes... items);
  public A removeAllFromMatch(Collection<TLSMatchAttributes> items);
  public A removeMatchingFromMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TLSMatchAttributes> getMatch();
  public List<TLSMatchAttributes> buildMatch();
  public TLSMatchAttributes buildMatch(int index);
  public TLSMatchAttributes buildFirstMatch();
  public TLSMatchAttributes buildLastMatch();
  public TLSMatchAttributes buildMatchingMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  public Boolean hasMatchingMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  public A withMatch(List<TLSMatchAttributes> match);
  public A withMatch(io.fabric8.istio.api.networking.v1alpha3.TLSMatchAttributes... match);
  public Boolean hasMatch();
  public TLSRouteFluent.MatchNested<A> addNewMatch();
  public TLSRouteFluent.MatchNested<A> addNewMatchLike(TLSMatchAttributes item);
  public TLSRouteFluent.MatchNested<A> setNewMatchLike(int index,TLSMatchAttributes item);
  public TLSRouteFluent.MatchNested<A> editMatch(int index);
  public TLSRouteFluent.MatchNested<A> editFirstMatch();
  public TLSRouteFluent.MatchNested<A> editLastMatch();
  public TLSRouteFluent.MatchNested<A> editMatchingMatch(Predicate<TLSMatchAttributesBuilder> predicate);
  public A addToRoute(int index,RouteDestination item);
  public A setToRoute(int index,RouteDestination item);
  public A addToRoute(io.fabric8.istio.api.networking.v1alpha3.RouteDestination... items);
  public A addAllToRoute(Collection<RouteDestination> items);
  public A removeFromRoute(io.fabric8.istio.api.networking.v1alpha3.RouteDestination... items);
  public A removeAllFromRoute(Collection<RouteDestination> items);
  public A removeMatchingFromRoute(Predicate<RouteDestinationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRoute instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteDestination> getRoute();
  public List<RouteDestination> buildRoute();
  public RouteDestination buildRoute(int index);
  public RouteDestination buildFirstRoute();
  public RouteDestination buildLastRoute();
  public RouteDestination buildMatchingRoute(Predicate<RouteDestinationBuilder> predicate);
  public Boolean hasMatchingRoute(Predicate<RouteDestinationBuilder> predicate);
  public A withRoute(List<RouteDestination> route);
  public A withRoute(io.fabric8.istio.api.networking.v1alpha3.RouteDestination... route);
  public Boolean hasRoute();
  public TLSRouteFluent.RouteNested<A> addNewRoute();
  public TLSRouteFluent.RouteNested<A> addNewRouteLike(RouteDestination item);
  public TLSRouteFluent.RouteNested<A> setNewRouteLike(int index,RouteDestination item);
  public TLSRouteFluent.RouteNested<A> editRoute(int index);
  public TLSRouteFluent.RouteNested<A> editFirstRoute();
  public TLSRouteFluent.RouteNested<A> editLastRoute();
  public TLSRouteFluent.RouteNested<A> editMatchingRoute(Predicate<RouteDestinationBuilder> predicate);
  public interface MatchNested<N> extends Nested<N>,TLSMatchAttributesFluent<TLSRouteFluent.MatchNested<N>>{
    public N and();
    public N endMatch();
    
  }
  public interface RouteNested<N> extends Nested<N>,RouteDestinationFluent<TLSRouteFluent.RouteNested<N>>{
    public N and();
    public N endRoute();
    
  }
  
}
